# Installation procedure for CryptPad
class profile::cryptpad::install (
  String  $revision                 = 'main',
  String  $http_address             = '127.0.0.1',
  String  $http_unsafe_origin       = 'example.com',
  String  $http_safe_origin         = 'sandbox.example.com',
  Array   $admin_keys               = [],
  Boolean $log_to_stdout            = true,
  Boolean $manage_nodejs_apt_source = false,
) {

  if $manage_nodejs_apt_source {
    apt::source { 'nodesource':
      location => 'https://deb.nodesource.com/node_16.x',
      release  => 'bullseye',
      repos    => 'main',
      key      => {
        id     => '9FD3B784BC1C6FC31A8A0A1C1655A0AB68576280',
        source => 'https://deb.nodesource.com/gpgkey/nodesource.gpg.key',
      },
    }
    $npm_packages = []
  } else {
    $npm_packages = [ 'npm' ]
  }

  ensure_packages([ 'nodejs' ] + $npm_packages)

  $home = '/srv/cryptpad'
  $repo = "${home}/cryptpad"

  accounts::user { 'cryptpad':
    home       => $home,
    managehome => true,
    system     => true,
  }

  vcsrepo { $repo:
    ensure   => present,
    provider => git,
    owner    => 'cryptpad',
    group    => 'cryptpad',
    source   => 'https://github.com/xwiki-labs/cryptpad.git',
    revision => $revision,
    notify   => Exec['cryptpad npm install'],
    require  => Accounts::User['cryptpad'],
  }

  exec { 'cryptpad npm install':
    command     => '/usr/bin/npm install',
    cwd         => $repo,
    user        => cryptpad,
    refreshonly => true,
    notify      => Exec['cryptpad npm install bower'],
  }

  exec { 'cryptpad npm install bower':
    command     => '/usr/bin/npm install bower',
    cwd         => $repo,
    user        => cryptpad,
    refreshonly => true,
    notify      => Exec['cryptpad bower install'],
  }

  exec { 'cryptpad bower install':
    command     => "${repo}/node_modules/bower/bin/bower install",
    cwd         => $repo,
    environment => [ "HOME=${home}" ],
    user        => cryptpad,
    refreshonly => true,
  }

  systemd::unit_file { 'cryptpad.service':
    source  => 'puppet:///modules/profile/cryptpad/cryptpad.service',
    require => Vcsrepo[$repo],
  }
  ~> service {'cryptpad':
    ensure => 'running',
  }

  file { "${repo}/config/config.js":
    ensure  => file,
    owner   => 'cryptpad',
    group   => 'cryptpad',
    mode    => '0600',
    content => epp('profile/cryptpad/config.js.epp', {
      http_address       => $http_address,
      http_unsafe_origin => "https://${http_unsafe_origin}",
      http_safe_origin   => "https://${http_safe_origin}",
      admin_keys         => $admin_keys,
      log_to_stdout      => $log_to_stdout,
    }),
    require => Vcsrepo[$repo],
    notify  => Service['cryptpad'],
  }

}
